summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kpayeesview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kpayeesview.h')
-rw-r--r--kmymoney2/views/kpayeesview.h65
1 files changed, 33 insertions, 32 deletions
diff --git a/kmymoney2/views/kpayeesview.h b/kmymoney2/views/kpayeesview.h
index 92f98fd..f4a481e 100644
--- a/kmymoney2/views/kpayeesview.h
+++ b/kmymoney2/views/kpayeesview.h
@@ -29,8 +29,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
-class QSplitter;
+#include <tqwidget.h>
+class TQSplitter;
// ----------------------------------------------------------------------------
// KDE Includes
@@ -57,7 +57,7 @@ class KListViewSearchLineWidget;
* vector is created, the sort method is set to SortPostDate.
* The sort type can be changed using the method setSortType().
*/
-class KTransactionPtrVector : public QPtrVector<KMyMoneyTransaction> {
+class KTransactionPtrVector : public TQPtrVector<KMyMoneyTransaction> {
public:
/**
* This enumerator defines the possible sort methods.
@@ -111,20 +111,20 @@ public:
* get information about the split referencing the current account
* during the sort phase.
*/
- void setAccountId(const QString& id);
+ void setAccountId(const TQString& id);
/**
* This method is used to set the payee id to have a chance to
* get information about the split referencing the current payee
* during the sort phase.
*/
- void setPayeeId(const QString& id);
+ void setPayeeId(const TQString& id);
protected:
int compareItems(KTransactionPtrVector::Item d1, KTransactionPtrVector::Item d2);
private:
- int compareItems(const QString& s1, const QString& s2) const;
+ int compareItems(const TQString& s1, const TQString& s2) const;
private:
enum {
@@ -132,7 +132,7 @@ private:
PayeeMode
};
short m_idMode;
- QString m_id;
+ TQString m_id;
TransactionSortE m_sortType;
};
@@ -147,20 +147,20 @@ public:
/**
* Constructor to be used to construct a payee entry object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param payee const reference to MyMoneyPayee for which
* the KListView entry is constructed
*/
- KPayeeListItem(KListView *parent, const MyMoneyPayee& payee);
+ KPayeeListItem(KListView *tqparent, const MyMoneyPayee& payee);
~KPayeeListItem();
/**
* This method is re-implemented from QListViewItem::paintCell().
* Besides the standard implementation, the QPainter is set
* according to the applications settings.
*/
- void paintCell(QPainter *p, const QColorGroup & cg, int column, int width, int align);
+ void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
const MyMoneyPayee& payee(void) const { return m_payee; };
@@ -175,48 +175,49 @@ private:
class KTransactionListItem : public KListViewItem
{
public:
- KTransactionListItem(KListView* view, KTransactionListItem* parent, const QString& accountId, const QString& transaction);
+ KTransactionListItem(KListView* view, KTransactionListItem* tqparent, const TQString& accountId, const TQString& transaction);
~KTransactionListItem();
- const QString& transactionId(void) const { return m_transactionId; };
+ const TQString& transactionId(void) const { return m_transactionId; };
- const QString& accountId(void) const { return m_accountId; };
+ const TQString& accountId(void) const { return m_accountId; };
/**
* use my own paint method
*/
- void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
/**
* use my own backgroundColor method
*/
- const QColor backgroundColor();
+ const TQColor backgroundColor();
private:
- QString m_transactionId;
- QString m_accountId;
+ TQString m_transactionId;
+ TQString m_accountId;
};
class KPayeesView : public KPayeesViewDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
- KPayeesView(QWidget *parent=0, const char *name=0);
+ KPayeesView(TQWidget *tqparent=0, const char *name=0);
~KPayeesView();
void show(void);
public slots:
- void slotSelectPayeeAndTransaction(const QString& payeeId, const QString& accountId = QString(), const QString& transactionId = QString());
+ void slotSelectPayeeAndTransaction(const TQString& payeeId, const TQString& accountId = TQString(), const TQString& transactionId = TQString());
void slotLoadPayees(void);
void slotStartRename(void);
void slotHelp(void);
protected:
- void resizeEvent(QResizeEvent*);
+ void resizeEvent(TQResizeEvent*);
void loadPayees(void);
- void selectedPayees(QValueList<MyMoneyPayee>& payeesList) const;
- void ensurePayeeVisible(const QString& id);
+ void selectedPayees(TQValueList<MyMoneyPayee>& payeesList) const;
+ void ensurePayeeVisible(const TQString& id);
void clearItemData(void);
protected slots:
@@ -244,7 +245,7 @@ protected slots:
* This slot is called when the name of a payee is changed inside
* the payee list view and only a single payee is selected.
*/
- void slotRenamePayee(QListViewItem *p, int col, const QString& txt);
+ void slotRenamePayee(TQListViewItem *p, int col, const TQString& txt);
/**
* Updates the payee data in m_payee from the information in the
@@ -252,7 +253,7 @@ protected slots:
*/
void slotUpdatePayee(void);
- void slotTransactionDoubleClicked(QListViewItem *);
+ void slotTransactionDoubleClicked(TQListViewItem *);
private slots:
void rearrange(void);
@@ -265,7 +266,7 @@ private slots:
* @param item the item on which the cursor resides
* @param p position of the pointer device
*/
- void slotOpenContextMenu(KListView* lv, QListViewItem* item, const QPoint& p);
+ void slotOpenContextMenu(KListView* lv, TQListViewItem* item, const TQPoint& p);
void slotQueueUpdate(void);
@@ -277,20 +278,20 @@ private:
void readConfig(void);
signals:
- void transactionSelected(const QString& accountId, const QString& transactionId);
+ void transactionSelected(const TQString& accountId, const TQString& transactionId);
void openContextMenu(const MyMoneyObject& obj);
- void selectObjects(const QValueList<MyMoneyPayee>& payees);
+ void selectObjects(const TQValueList<MyMoneyPayee>& payees);
private:
MyMoneyPayee m_payee;
- QString m_newName;
+ TQString m_newName;
- QSplitter* m_splitter;
+ TQSplitter* m_splitter;
/**
* This member holds a list of all transactions
*/
- QValueList<KMyMoneyTransaction> m_transactionList;
+ TQValueList<KMyMoneyTransaction> m_transactionList;
/**
* This member keeps a vector of pointers to all visible (filtered)
@@ -147,20 +147,20 @@ public:
* Constructor to be used to construct a payee entry object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param tqparent pointer to the KListView object this entry should be
* added to.
* @param payee const reference to MyMoneyPayee for which
@@ -147,20 +147,20 @@ public:
~KPayeeListItem();
/**
- * This method is re-implemented from QListViewItem::paintCell().
- * Besides the standard implementation, the QPainter is set
+ * This method is re-implemented from TQListViewItem::paintCell().
+ * Besides the standard implementation, the TQPainter is set
* according to the applications settings.
*/